@@ -55,14 +55,20 @@ class AbstractContext:
 
     # Magic variables.
 
-    def width(self):
+    def _get_width(self):
         """Answers the width of the current page."""
         raise NotImplementedError
 
-    def height(self):
+    width = property(_get_width)
+
+    def _get_height(self):
         """Answers the height of the current page."""
         raise NotImplementedError
 
+    height = property(_get_height)
+
+    # Size.
+
     def sizes(self, paperSize=None):
         """Returns the (w, h) of a specified canvas size. If no canvas size is
         given it will return the dictionary containing all possible page sizes.
@@ -83,13 +89,22 @@ class AbstractContext:
             return PAGE_SIZES
         return PAGE_SIZES.get(paperSize)
 
+    '''
+    def setSize(self, w, h=None):
+        """Sets the width and height of the current page. Standardize on
+        PageBot `(w, h)` for consistent naming, instead of DrawBot (width,
+        height)."""
+        raise NotImplementedError
+
+    '''
+
     def pageCount(self):
         """Answer the current page count."""
         raise NotImplementedError
 
     # Public callbacks.
 
-    def newPage(self, w=None, h=None, page=None, **kwargs):
+    def newPage(self, w=None, h=None, doc=None, **kwargs):
         """Optional width and height if defined. Standardize on PageBot `(w,
         h)` for consistent naming, instead of DrawBot (width, height).
         Otherwise the optional PageBot `page` instance can be used by the
@@ -101,13 +116,8 @@ class AbstractContext:
         (pages are stored in the Document instance, not in the context),
         other than for the DrawBot context to make it compatible."""
         raise NotImplementedError
-    pages = property(_get_pages)
 
-    def size(self, w, h=None):
-        """Sets the width and height of the current page. Standardize on
-        PageBot `(w, h)` for consistent naming, instead of DrawBot (width,
-        height)."""
-        raise NotImplementedError
+    pages = property(_get_pages)
 
     def saveImage(self, path, *args, **options):
         """Save or export the canvas to a specified format. The `path`
@@ -491,9 +501,6 @@ class AbstractContext:
     def imagePixelColor(self, path, p):
         raise NotImplementedError
 
-    def numberOfPages(self, path):
-        raise NotImplementedError
-
     # Mov.
 
     def frameDuration(self, secondsPerFrame):
