@@ -18,6 +18,8 @@
 import math
 import booleanOperations
 from fontTools.pens.basePen import BasePen
+from fontTools.pens.pointPen import PointToSegmentPen
+from fontTools.pens.boundsPen import BoundsPen
 from pagebot.errors import PageBotError
 from pagebot.contexts.basecontext.basebeziercontour import BaseBezierContour
 from pagebot.contexts.basecontext.basebezierpoint import BaseBezierPoint
@@ -135,18 +137,29 @@ class BaseBezierPath(BasePen):
         point = BaseBezierPoint(x, y, onCurve=onCurve)
         return point
 
-    # Drawing.
+    # FontTools PointToSegmentPen routines.
 
     def beginPath(self, identifier=None):
-        """Begins the path as a point pen and starts a new subpath."""
-        raise NotImplementedError
+        """Begin using the path as a point pen and start a new subpath."""
+        self._pointToSegmentPen = PointToSegmentPen(self)
+        self._pointToSegmentPen.beginPath()
 
     def addPoint(self, point, segmentType=None, smooth=False, name=None,
             identifier=None, **kwargs):
-        """Uses the path as a point pen and add a point to the current subpath.
+        """Use the path as a point pen and add a point to the current subpath.
         `beginPath` must have been called prior to adding points with
         `addPoint` calls."""
-        raise NotImplementedError
+        if not hasattr(self, "_pointToSegmentPen"):
+            msg = "path.beginPath() must be called before the path can be used as a point pen."
+            raise PageBotError(msg)
+        self._pointToSegmentPen.addPoint(
+            point,
+            segmentType=segmentType,
+            smooth=smooth,
+            name=name,
+            identifier=identifier,
+            **kwargs
+        )
 
     def endPath(self):
         """Ends the current subpath. Calling this method has two distinct
@@ -159,7 +172,40 @@ class BaseBezierPath(BasePen):
         When the Bézier path is used as a point pen (using `beginPath`,
         `addPoint` and `endPath`), the path will process all the points added
         with `addPoint`, finishing the current subpath."""
-        raise NotImplementedError
+        if hasattr(self, "_pointToSegmentPen"):
+            pointToSegmentPen = self._pointToSegmentPen
+            del self._pointToSegmentPen
+            pointToSegmentPen.endPath()
+        else:
+            msg = "path.beginPath() must be called before the path can be used as a point pen."
+            raise PageBotError(msg)
+
+    def draw(self, pen):
+        """Draws the contours with **pen**."""
+        pointPen = PointToSegmentPen(pen)
+        self.drawToPointPen(pointPen)
+
+    def bounds(self):
+        """Returns the bounding box of the path."""
+        pen = BoundsPen(self)
+        self.draw(pen)
+        return pen.bounds
+
+    def drawToPointPen(self, pointPen):
+        """Draws the Bézier path into a point pen."""
+        contours = self.contours
+
+        for contour in contours:
+            contour.drawToPointPen(pointPen)
+
+    def drawToPen(self, pen):
+        """Draws the Bézier path into a pen."""
+        contours = self.contours
+
+        for contour in contours:
+            contour.drawToPen(pen)
+
+    # Drawing.
 
     def addComponent(self, glyphName, transformation):
         """
@@ -173,16 +219,73 @@ class BaseBezierPath(BasePen):
         """
         raise NotImplementedError
 
-    def drawToPen(self, pen):
-        """Draws the Bézier path into a pen."""
-        raise NotImplementedError
-
-    def drawToPointPen(self, pointPen):
-        """Draws the Bézier path into a point pen."""
-        raise NotImplementedError
-
     # Shapes.
 
+    def rect(self, x, y, w, h):
+        """Adds a rectangle at position `x`, `y` with a size of `w`, `h`."""
+        x1 = x + w
+        y1 = y + h
+        p0 = (x, y)
+        p1 = (x1, y)
+        p2 = (x1, y1)
+        p3 = (x, y1)
+        self.moveTo(p0)
+        self.lineTo(p1)
+        self.lineTo(p2)
+        self.lineTo(p3)
+        self.closePath()
+
+    def oval(self, x, y, w, h):
+        """Adds an oval at position `x`, `y` with a size of `w`, `h`"""
+        # Control point offsets.
+        kappa = .5522848
+        offsetX = (w / 2) * kappa
+        offsetY = (h / 2) * kappa
+
+        # Middle and other extreme points.
+        x0 = x + (w / 2)
+        y0 = y + (h / 2)
+        x1 = x + w
+        y1 = y + h
+
+        self.moveTo((x0, y0))
+
+        cp1 = (x, y0 - offsetY)
+        cp2 = (x0 - offsetX, y)
+        p = (x1, y0)
+        self.curveTo(cp1, cp2, p)
+
+        cp1 = (x0 + offsetX, y)
+        cp2 = (x1, y0 - offsetY)
+        p = (x1, y0)
+        self.curveTo(cp1, cp2, p)
+
+        cp1 = (x1, y0 + offsetY)
+        cp2 = (x0 + offsetX, y1)
+        p = (x0, y1)
+        self.curveTo(cp1, cp2, p)
+
+        cp1 = (x0 - offsetX, y1)
+        cp2 = (x, y0 + offsetY)
+        p = (x, y0)
+        self.curveTo(cp1, cp2, p)
+
+    def line(self, point1, point2):
+        """Adds a line between two given points."""
+        self.moveTo(point1)
+        self.lineTo(point2)
+
+    def polygon(self, *points, **kwargs):
+        """Draws a polygon with `n` points. Optionally a `close` argument can
+        be provided to open or close the path. By default a `polygon` is a
+        closed path."""
+        self.moveTo(points[0])
+
+        for point in points[1:]:
+            self.lineTo(point)
+
+        # TODO: optionally close.
+
     def arc(self, center, radius, startAngle, endAngle, clockwise):
         """Arc with `center` and a given `radius`, from `startAngle` to
         `endAngle`, going clockwise if `clockwise` is True and counter
@@ -196,23 +299,7 @@ class BaseBezierPath(BasePen):
         legs of the angle."""
         raise NotImplementedError
 
-    def rect(self, x, y, w, h):
-        """Adds a rectangle at position `x`, `y` with a size of `w`, `h`."""
-        raise NotImplementedError
-
-    def oval(self, x, y, w, h):
-        """Adds an oval at position `x`, `y` with a size of `w`, `h`"""
-        raise NotImplementedError
-
-    def line(self, point1, point2):
-        """Adds a line between two given points."""
-        raise NotImplementedError
-
-    def polygon(self, *points, **kwargs):
-        """Draws a polygon with `n` points. Optionally a `close` argument can
-        be provided to open or close the path. By default a `polygon` is a
-        closed path."""
-        raise NotImplementedError
+    # Text.
 
     def text(self, txt, offset=None, font=_FALLBACKFONT, fontSize=10,
             align=None):
@@ -246,7 +333,6 @@ class BaseBezierPath(BasePen):
         raise NotImplementedError
 
     # Path operations.
-
     # These are specific for a DrawBot path, dropping from interface.
 
     #def getNSBezierPath(self):
