@@ -16,27 +16,31 @@
 #
 
 import os
+from os.path import exists
 from math import radians, sin, cos
 import xml.etree.ElementTree as ET
-import PIL
+from PyPDF2 import PdfFileReader
 
-from pagebot.constants import (LEFT, RIGHT, CENTER, DISPLAY_BLOCK,
-        DEFAULT_FRAME_DURATION, DEFAULT_FONT_SIZE, DEFAULT_LANGUAGE,
-        DEFAULT_WIDTH, FILETYPE_SVG, FILETYPE_PDF, DEFAULT_FONT, XXXL)
+from pagebot.constants import (LEFT, RIGHT, CENTER, DEFAULT_FRAME_DURATION,
+        DEFAULT_FONT_SIZE, DEFAULT_LANGUAGE, DEFAULT_WIDTH, FILETYPE_SVG,
+        FILETYPE_PDF, DEFAULT_FONT, XXXL)
 from pagebot.contexts.basecontext.abstractcontext import AbstractContext
 from pagebot.contexts.basecontext.babelstring import BabelString
 from pagebot.errors import PageBotFileFormatError
 from pagebot.fonttoolbox.objects.font import findFont
+from pagebot.style import makeStyle
 from pagebot.toolbox.color import (color, noColor, Color, inheritColor,
         blackColor)
 from pagebot.toolbox.transformer import path2Extension
 from pagebot.toolbox.units import upt, pt, point2D, Angle, Pt
-from pagebot.style import makeStyle
+
+HAS_PIL = True
 
 try:
-    from PyPDF2 import PdfFileReader
-except ImportError:
-    pass
+    from PIL import Image
+except:
+    print('FlatContext: Warning, missing PIL')
+    HAS_PIL = False
 
 class BaseContext(AbstractContext):
     """Base API for all contexts. Extends the DrawBot interface.
@@ -80,6 +84,10 @@ class BaseContext(AbstractContext):
         self._pages = []
         self.style = None
         self.units = Pt.UNIT
+        self.hasPIL = False
+
+        if HAS_PIL:
+            self.hasPIL = True
 
     def __repr__(self):
         return '<%s>' % self.name
@@ -122,56 +130,68 @@ class BaseContext(AbstractContext):
     language = property(_get_language, _set_language)
     '''
 
-    # Magic variables.
-
-    def width(self):
-        return self.b.width()
-
-    def height(self):
-        return self.b.height()
-
-    def sizes(self, paperSize=None):
-        return self.b.sizes(paperSize=paperSize)
-
-    def pageCount(self):
-        return self.b.pageCount()
-
-    # Public callbacks.
-
-    def size(self, width, height=None):
-        return self.b.size(width, height=height)
-
-    def setSize(self, w=None, h=None):
-        # TODO: also add to abstract.
-        pass
-
-    def newPage(self, w=None, h=None, doc=None, **kwargs):
-        """Creates a new drawbot page.
-
-        >>> from pagebot.toolbox.units import px
-        >>> from pagebot import getContext
-        >>> context = getContext()
-        >>> context.newPage(pt(100), pt(100))
-       >>> context.newPage(100, 100)
-        """
-        if doc is not None:
-            w = w or doc.w
-            h = h or doc.h
-        wpt, hpt = upt(w, h)
-        self.b.newPage(wpt, hpt)
+    # Saving / export.
 
     def saveImage(self, path, *args, **options):
-        return self.b.saveImage(path, *args, **options)
+        pass
+
+    def export(self, fileName, folderName=None, extension=None):
+        pass
+
+    # Image scaling.
 
     def scaleImage(self, path, w, h, index=None, showImageLoresMarker=False,
             exportExtension=None, force=False):
-        """TODO: Should scale an image at `path` and save it to another file
-        with Pillow."""
-        # FIXME: scale with PIL
-        #context = getContext()
-        #return context.scaleImage(path, w, h, index=index,
-        #    showImageLoresMarker=showImageLoresMarker, exportExtension=exportExtension,
-        #    force=force)
+        """Scales image and stores it to _scaled/image-name.ext.
+
+        TODO: show optional low resolution marker? Or remove it?
+        TODO: add optional extensions.
+        TODO: move to shared base.
+        TODO: check if index is still necessary.
+        """
+        assert exists(path)
+        assert self.hasPIL
+        im = Image.open(path)
+        path, ext = self.getResizedPathName(path, w, h)
+
+        if ext == 'jpg':
+            ext = 'jpeg'
+
+        if force or not exists(path):
+            try:
+                im = im.resize((w, h), Image.ANTIALIAS)
+            except OverflowError as e:
+                print('%s: Caught an OverflowError:' % self.name, e)
+                print('Image path is %s' % path)
+            im.save(path, ext)
+
+        return path
+
+    # Older implementation, shows image and optional message.
+    '''
+    cachePath, fileName = self.path2ScaledImagePath(path, w, h, index, exportExtension)
+
+    # If default _scaled directory does not exist, then create it.
+    if not exists(cachePath):
+        os.makedirs(cachePath)
+    cachedFilePath = cachePath + fileName
+
+    if force or not os.path.exists(cachedFilePath):
+        # Clean the drawing stack.
+        self.image(path, (0, 0), w=w, h=h, pageNumber=index or 0)
+
+        if showImageLoresMarker:
+            bs = self.newString('LO-RES',
+                    style=dict(font=DEFAULT_FALLBACK_FONT_PATH,
+                        fontSize=pt(64), fill=color(0, 1, 1),
+                        textFill=color(1, 0, 0)))
+            tw, th = bs.textSize
+            self.text(bs, (w/2-tw/2, h/2-th/4))
+        self.saveImage(cachedFilePath)
+
+        # Clean the drawing stack again.
+    return cachedFilePath
+    '''
 
 
     def printImage(self, pdf=None):
@@ -336,7 +356,7 @@ class BaseContext(AbstractContext):
     '''
     def quadTo(self, bcp, p):
         # TODO: Convert to Bezier with 0.6 rule
-        # What's difference with qCurveTo()?
+        # Same output as qCurveTo()?
         return self.b.quadTo(bcp, p)
     '''
 
@@ -350,7 +370,6 @@ class BaseContext(AbstractContext):
 
     def closePath(self):
         """Closes the open path if it exists, otherwise ignore it.
-        PageBot function.
 
         >>> from pagebot import getContext
         >>> context = getContext()
@@ -682,7 +701,29 @@ class BaseContext(AbstractContext):
     def lineDash(self, value):
         """LineDash is None or a list of dash lengths."""
 
-    # Transform.
+    # Scale.
+
+    def getScaledWH(self, w, h):
+        """Scales width and height according to previously set scale."""
+        return w * self._sx, h * self._sy
+
+    # Transformations.
+
+    def translatePoint(self, p):
+        """Simpler function to translate a point based on origin coordinates
+        (`self._ox` and `self._oy`).
+
+        TODO: merge with getTransformed.
+        """
+        x, y = point2D(upt(p))
+        x = self._ox + x
+
+        '''Because the origin is at the bottom, like in DrawBot and as opposed
+        to Flat, we need to subtract all vertical coordinates from the page
+        height before an object gets placed. In case of (bounding) boxes, we
+        also need to subtract the box height.'''
+        y = self.height - (self._oy + y)
+        return upt(x, y)
 
     def transform(self, matrix, center=(0, 0)):
         """Transform canvas over matrix t, e.g. (1, 0, 0, 1, dx, dy) to shift
@@ -971,32 +1012,6 @@ class BaseContext(AbstractContext):
     def newBulletString(self, bullet, style=None):
         return self.newString(bullet, style=style)
 
-    def XXXnewText(self, textStyles, newLine=False):
-        """Answers a BabelString as a combination of all text and styles in
-        textStyles, which is should have format:
-
-        [(baseString, style), (baseString, style), ...]
-
-        Add return \n to the string is the newLine attribute is True or if a
-        style has
-
-        style.get('display') == DISPLAY_BLOCK
-
-        """
-        assert isinstance(textStyles, (tuple, list))
-        s = None
-
-        for t, style in textStyles:
-            if newLine or (style and style.get('display') == DISPLAY_BLOCK):
-                t += '\n'
-
-            bs = self.newString(t, style=style)
-            if s is None:
-                s = bs
-            else:
-                s += bs
-        return s
-
     # Images.
 
     def image(self, path, p, alpha=1, pageNumber=None, w=None, h=None,
@@ -1005,6 +1020,9 @@ class BaseContext(AbstractContext):
         return self.b.image(path, p, alpha=alpha, pageNumber=pageNumber, w=w,
                 h=h, scaleType=scaleType)
 
+    '''
+    Should be same as pageCount().
+
     def numberOfPages(self, path):
         """Answer the number of pages, if the image paths points to a PDF.
         https://www.journaldev.com/33281/pypdf2-python-library-for-pdf-files
@@ -1025,6 +1043,7 @@ class BaseContext(AbstractContext):
                 information = pdf.getDocumentInfo()
                 return pdf.getNumPages()
         return None
+    '''
 
     def imageSize(self, path, index=0):
         """Answer the images size of path.
@@ -1044,21 +1063,25 @@ class BaseContext(AbstractContext):
         (400pt, 200pt)
         """
         extension = path2Extension(path)
+
         if extension == FILETYPE_PDF:
             im = PdfFileReader(open(path, 'rb'))
             r = im.getPage(0).mediaBox # RectangleObject([0, 0, w, h])
             w = float(r.getWidth())
             h = float(r.getHeight())
             return pt(w, h)
-
-        if extension == FILETYPE_SVG:
+        elif extension == FILETYPE_SVG:
             svgTree = ET.parse(path)
             # FIXME: Answer the real size from the XML tree
             return pt(1000, 1000)
 
-        # Using Pillow for other image formats
-        image = PIL.Image.open(path)
-        return pt(image.size)
+        elif self.hasPIL:
+            # Using Pillow for other image formats.
+            # TODO: check compatible formats first.
+            image = Image.open(path)
+            return pt(image.size)
+        else:
+            return None
 
     def imagePixelColor(self, path, p):
         return self.b.imagePixelColor(path, p)
