@@ -18,59 +18,25 @@ import math
 from sys import platform
 from os import listdir, makedirs
 from os.path import exists
-import flat
-from flat import rgb
+#from flat import rgb
 
 from pagebot.constants import (DEFAULT_FONT, DEFAULT_FONT_SIZE, FILETYPE_PDF,
         FILETYPE_JPG, FILETYPE_SVG, FILETYPE_PNG, FILETYPE_GIF, LEFT,
-        DEFAULT_FILETYPE, RGB, CENTER, RIGHT)
+        DEFAULT_FILETYPE, RGB, CENTER, RIGHT, EXPORT)
 from pagebot.contexts.basecontext.basecontext import BaseContext
 from pagebot.contexts.basecontext.babelstring import BabelString
 from pagebot.contexts.basecontext.babelrun import BabelLineInfo, BabelRunInfo
 from pagebot.contexts.flatcontext.flatbuilder import flatBuilder
 from pagebot.contexts.flatcontext.flatbezierpath import FlatBezierPath
+from pagebot.contexts.flatcontext.flatrundata import FlatRunData
+from pagebot.contexts.flatcontext.flatbabeldata import FlatBabelData
 from pagebot.filepaths import ROOT_FONT_PATHS
 from pagebot.fonttoolbox.fontpaths import getFontPathOfFont
 from pagebot.fonttoolbox.objects.font import findFont, Font
 from pagebot.mathematics import to255
 from pagebot.mathematics.transform3d import Transform3D
 from pagebot.toolbox.color import color, Color, noColor, blackColor
-from pagebot.toolbox.units import pt, em, upt, point2D, units
-
-
-HAS_PIL = True
-
-try:
-    from PIL import Image
-except:
-    print('FlatContext: Warning, missing PIL')
-    HAS_PIL = False
-
-class FlatBabelData:
-    """Class to store cached information in BabelString._cs."""
-
-    def __init__(self, doc, page, paragraphs, runs):
-        self.doc = doc # Flat.document instance
-        self.page = page # Flat.page instance
-        self.paragraphs = paragraphs
-        self.txt = flat.text(paragraphs)
-        self.pt = page.place(self.txt) # Flat.placedText instance
-        self.runs = runs # List of FlatRunData instances
-
-    def __repr__(self):
-        spans = [span.string for p in self.paragraphs for span in p.spans]
-        # Show plain string accumulate string, compatible to DrawBotFormattedString
-        return ' '.join(spans)
-
-class FlatRunData:
-    """Class to store cached information in FlatBabelData.runs."""
-
-    def __init__(self, st, pars):
-        self.st = st # Current strike for this run.
-        self.pars = pars # Current list of paragraphs that share the same strike.
-
-    def __repr__(self):
-        return '<%s>' % self.__class__.__name__
+from pagebot.toolbox.units import pt, em, upt, units
 
 class FlatContext(BaseContext):
     """The FlatContext implements the Flat functionality within the PageBot
@@ -119,7 +85,8 @@ class FlatContext(BaseContext):
 
         >>> context = FlatContext()
         >>> context.newPage(100, 100)
-        >>> context.drawing.__class__.__name__
+        >>> drawing = context.getDrawing()
+        >>> drawing.__class__.__name__
         'document'
         """
         super().__init__()
@@ -131,10 +98,11 @@ class FlatContext(BaseContext):
         # Current open shape.
         self.shape = None
         self.fileType = DEFAULT_FILETYPE
-        self.drawing = None
+        self._drawing = None
         self._numberOfPages = 0
         self._flatFonts = {} # Caching of {font.path:flatFont}
         self.setTransform3D()
+        self._numberOfPages = 0
 
     def setTransform3D(self):
         """Initializes the transforrmation matrix to be used for translation,
@@ -142,22 +110,15 @@ class FlatContext(BaseContext):
         self.transform3D = Transform3D()
 
     #   Drawing.
+    #
+    #   Like in DrawBot, newDrawing creates a new page, while new page creates
+    #   a drawing if it doesn't exist yet. Drawing size is taken from the element
+    #   level document, from size tuple, from w and h, or is set to 1000 x 1000px
+    #   in that order. Changing of drawing size over multiple pages still needs to
+    #   be supported.
 
-    def newDrawing(self, w=None, h=None, size=None, doc=None):
-        """Creates a new Flat canvas to draw on. Flipped `y`-axis by default to
-        conform to DrawBot's drawing methods.
-
-        >>> context = FlatContext()
-        >>> context.newPage(100, 100)
-        >>> int(context.drawing.width), int(context.drawing.height)
-        (100, 100)
-        """
-
-        if self.drawing:
-            self.clear()
-
-        #self.originTop = originTop
-        #self.originTop = False
+    def getDrawingSize(self, w=None, h=None, size=None, doc=None):
+        """We assume origin is at the bottom, just like in DrawBot."""
 
         if doc is not None:
             w = doc.w
@@ -165,6 +126,7 @@ class FlatContext(BaseContext):
         elif size is not None:
             w, h = size
 
+        w, h = self._getValidSize(w, h)
 
         # Dimensions not allowed to be None or Flat document won't render.
         assert w is not None
@@ -172,12 +134,69 @@ class FlatContext(BaseContext):
 
         # Converts units to point values. Stores width and height information
         # in Flat document.
-        wpt, hpt = upt(w, h)
-        self.drawing = self.b.document(wpt, hpt, units=self.UNITS)
-        #self.drawing.size(wpt, hpt, units=self.UNITS)
-        #self.drawing.pages = []
+        return upt(w, h)
 
-    def saveDrawing(self, path, multiPage=True):
+    def _getValidSize(self, w, h):
+        """Answer a valid size for FlatContext document and pages. Make
+        default page size, similar to DrawBot."""
+        if w is None or w < 0:
+            w = pt(1000)
+        if h is None or h < 0:
+            h = pt(1000)
+
+        return units(w), units(h)
+
+    def newDrawing(self, w=None, h=None, size=None, doc=None, doPage=True):
+        """Creates a new Flat canvas to draw on. Flipped `y`-axis by default to
+        conform to DrawBot's drawing methods.
+
+        >>> context = FlatContext()
+        >>> context.newPage(100, 100)
+        >>> drawing = context.getDrawing()
+        >>> int(drawing.width), int(drawing.height)
+        (100, 100)
+        """
+
+        if self._drawing:
+            self.clear()
+
+        wpt, hpt = self.getDrawingSize(w=w, h=h, size=size, doc=doc)
+        self._drawing = self.b.document(wpt, hpt, units=self.UNITS)
+        if doPage:
+            self.newPage(w=w, h=h)
+
+    def newPage(self, w=None, h=None, doc=None, **kwargs):
+        """Other page sizes than default in self._drawing are ignored in Flat.
+
+        NOTE: this generates a flat.page, not to be confused with PageBot page.
+        TODO: when size changes, keep track of multiple Flat documents.
+        Alternatively, we can try to resize, but not sure what happens with the
+        dimensions of previous pages (needs testing).
+
+        self._drawing.size(wpt, hpt, units=self.UNITS)
+
+        documents::
+
+            if w != self.w:
+                <add document to stack>
+            if h != self.h
+                <add document to stack>
+
+        >>> from pagebot.toolbox.units import pt
+        >>> context = FlatContext()
+        >>> w = h = pt(100)
+        >>> context.newPage(w, h)
+        """
+        w, h = self.getDrawingSize(w=w, h=h, doc=doc)
+
+        if not self._drawing:
+            self.newDrawing(w=w, h=h, doPage=False)
+
+        assert self._drawing
+        self._numberOfPages += 1
+        self._drawing.addpage()
+
+    def saveDrawing(self, path, multiPage=None):
         """Save the current document to file(s)
 
         >>> import os
@@ -215,36 +234,37 @@ class FlatContext(BaseContext):
         >>> context.saveDrawing(exportPath + '/MyTextDocument_F.gif')
         [FlatContext] Gif not yet implemented for "MyTextDocument_F.gif"
         """
+        if not multiPage:
+            multiPage = True
         # In case path starts with "_export", make sure that the directory
         # exists.
         self.checkExportPath(path)
         self.fileType = path.split('.')[-1].lower()
 
         if self.fileType == FILETYPE_PNG:
-            if len(self.drawing.pages) == 1 or not multiPage:
-                im = self.drawing.pages[0].image(kind=RGB)
+            if len(self._drawing.pages) == 1 or not multiPage:
+                im = self._drawing.pages[0].image(kind=RGB)
                 im.png(path)
             else:
-                for n, p in enumerate(self.drawing.pages):
+                for n, p in enumerate(self._drawing.pages):
                     pagePath = path.replace('.'+FILETYPE_PNG, '%03d.%s' % (n, FILETYPE_PNG))
                     p.image(kind=RGB).png(pagePath)
-
         elif self.fileType == FILETYPE_JPG:
-            if len(self.drawing.pages) == 1 or not multiPage:
-                self.drawing.pages[0].image(kind=RGB).jpeg(path)
+            if len(self._drawing.pages) == 1 or not multiPage:
+                self._drawing.pages[0].image(kind=RGB).jpeg(path)
             else:
-                for n, p in enumerate(self.drawing.pages):
+                for n, p in enumerate(self._drawing.pages):
                     pagePath = path.replace('.'+FILETYPE_PNG, '%03d.%s' % (n, FILETYPE_PNG))
                     p.image(kind=RGB).jpeg(pagePath)
         elif self.fileType == FILETYPE_SVG:
-            if len(self.drawing.pages) == 1 or not multiPage:
-                self.drawing.pages[0].svg(path)
+            if len(self._drawing.pages) == 1 or not multiPage:
+                self._drawing.pages[0].svg(path)
             else:
-                for n, p in enumerate(self.drawing.pages):
+                for n, p in enumerate(self._drawing.pages):
                     pagePath = path.replace('.'+FILETYPE_SVG, '%03d.%s' % (n, FILETYPE_SVG))
                     p.svg(pagePath)
         elif self.fileType == FILETYPE_PDF:
-            self.drawing.pdf(path) # Cannot render rgba.
+            self._drawing.pdf(path) # Cannot render rgba.
         elif self.fileType == FILETYPE_GIF:
             msg = '[FlatContext] Gif not yet implemented for "%s"' % path.split('/')[-1]
             print(msg)
@@ -252,6 +272,19 @@ class FlatContext(BaseContext):
             msg = '[FlatContext] File format "%s" is not implemented' % path.split('/')[-1]
             raise NotImplementedError(msg)
 
+    # Compatibility with DrawBot API.
+    saveImage = saveDrawing
+
+    def export(self, fileName, folderName=None, extension=None):
+        """Saves file to filename with default folder name and extension."""
+        if not folderName:
+            folderName = EXPORT
+        if not extension:
+            extension = 'pdf'
+
+        path = '%s/%s.%s' % (folderName, fileName, extension)
+        self.saveImage(path)
+
     # Styles
 
     def setStyles(self, styles):
@@ -262,88 +295,22 @@ class FlatContext(BaseContext):
     # Magic variables.
 
     def pageCount(self):
-        pass
+        return self._numberOfPages
 
     # Public callbacks.
 
-    '''
-    def scaleImage(self, path, w, h, index=None, showImageLoresMarker=False,
-            exportExtension=None, force=False):
-        # TODO
-
-        cachePath, fileName = self.path2ScaledImagePath(path, w, h, index, exportExtension)
-
-        # If default _scaled directory does not exist, then create it.
-        if not exists(cachePath):
-            os.makedirs(cachePath)
-        cachedFilePath = cachePath + fileName
-
-        if force or not os.path.exists(cachedFilePath):
-            # Clean the drawing stack.
-            self.image(path, (0, 0), w=w, h=h, pageNumber=index or 0)
-
-            if showImageLoresMarker:
-                bs = self.newString('LO-RES',
-                        style=dict(font=DEFAULT_FALLBACK_FONT_PATH,
-                            fontSize=pt(64), fill=color(0, 1, 1),
-                            textFill=color(1, 0, 0)))
-                tw, th = bs.textSize
-                self.text(bs, (w/2-tw/2, h/2-th/4))
-            self.saveImage(cachedFilePath)
-
-            # Clean the drawing stack again.
-        return cachedFilePath
-        return path
-    '''
-
-    def scaleImage(self, path, w, h, index=None, showImageLoresMarker=False,
-            exportExtension=None, force=False):
-        """Scales image and stores it to _scaled/image-name.jpg.
-
-        NOTE: using PIL for resizing, much faster than Flat.
-        TODO: show optional lores marker? Or remove it?
-        TODO: add optional extensions.
-        TODO: move to shared base.
-        TODO: check if index is still necessary.
-        """
-
-        im = Image.open(path)
-        path, ext = self.getResizedPathName(path, w, h)
-
-        if ext == 'jpg':
-            ext = 'jpeg'
-
-        if force or not exists(path):
-            try:
-                im = im.resize((w, h), Image.ANTIALIAS)
-            except OverflowError as e:
-                print('%s: Caught an OverflowError:' % self.name, e)
-                print('Image path is %s' % path)
-            im.save(path, ext)
-
-        return path
-
-    # Compatible API with DrawBot.
-    saveImage = saveDrawing
-
     def endDrawing(self, doc=None):
-        self.drawing = None
+        self._drawing = None
 
     def clear(self):
         self.endDrawing()
         self._numberOfPages = 0
 
     def getDrawing(self):
-        return self.drawing
-
-    def _getValidSize(self, w, h):
-        """Answer a valid size for FlatContext document and pages."""
-        if w is None or w < 0:
-            w = pt(1000) # Make default page size, similar to DrawBot.
-        if h is None or h < 0:
-            h = pt(1000)
-        return units(w), units(h)
+        """Returns the drawing object in the current state."""
+        return self._drawing
 
+    '''
     def setSize(self, w=None, h=None):
         """Set the initial page size of the context, in case something is drawn
         before a document or page is created.
@@ -367,36 +334,9 @@ class FlatContext(BaseContext):
         (100mm, 200cm)
         """
         #self.w, self.h = self._getValidSize(w, h)
-        # TODO: see if Flat document can be resized, else we should probably
-        # create a new one.
-
-    def newPage(self, w=None, h=None, doc=None):
-        """Other page sizes than default in self.drawing, are ignored in Flat.
-
-        NOTE: this generates a flat.page, not to be confused with PageBot page.
-        FIXME: test units, page auto-sizes to parent doc.
-        TODO: when size changes, we need to keep track of multiple Flat
-        documents::
-
-            if w != self.w:
-                <add document to stack>
-            if h != self.h
-                <add document to stack>
-
-        >>> from pagebot.toolbox.units import pt
-        >>> context = FlatContext()
-        >>> w = h = pt(100)
-        >>> context.newPage(w, h)
-        """
-        w, h = self._getValidSize(w, h)
-
-        if not self.drawing:
-            self.newDrawing(w=w, h=h)
-
-        assert self.drawing
-
-        self._numberOfPages += 1
-        self.drawing.addpage()
+        # TODO: see if Flat document can be resized, else we should create a
+        # new one and copy its contents.
+    '''
 
     def getTmpPage(self, w, h):
         drawing = self.b.document(w, h, units=self.UNITS)
@@ -407,25 +347,27 @@ class FlatContext(BaseContext):
         W = 800
         H = 600
 
-        if self.drawing is None:
+        if self._drawing is None:
             self.newDrawing(w=W, h=H)
         if self._numberOfPages == 0:
             self.newPage(w=W, h=H)
 
-        assert self.drawing
-        assert self.drawing.pages
-        return self.drawing.pages[-1]
+        assert self._drawing
+        assert self._drawing.pages
+        return self._drawing.pages[-1]
 
     page = property(_get_page)
 
-    def _get_height(self):
-        return self.drawing.height
-    height = property(_get_height)
-
     def _get_width(self):
-        return self.drawing.width
+        return self._drawing.width
+
     width = property(_get_width)
 
+    def _get_height(self):
+        return self._drawing.height
+
+    height = property(_get_height)
+
     def getTransformed(self, x, y, z=0):
         """Takes a point and puts it through the transformation matrix,
         handling translation, rotation and scaling at once.
@@ -472,27 +414,6 @@ class FlatContext(BaseContext):
         y1 = self.height - y1
         return upt(x1, y1)
 
-    def translatePoint(self, p):
-        """
-        Simpler function to translate a point based on origin coordinates
-        (`self._ox` and `self._oy`).
-
-        TODO: merge with getTransformed.
-        """
-        x, y = point2D(upt(p))
-        x = self._ox + x
-
-        '''Because the origin is at the bottom, like in DrawBot and as opposed
-        to Flat, we need to subtract all vertical coordinates from the page
-        height before an object gets placed. In case of (bounding) boxes, we
-        also need to subtract the box height.'''
-        y = self.height - (self._oy + y)
-        return upt(x, y)
-
-    def getScaledWH(self, w, h):
-        """Scales width and height according to previously set scale."""
-        return w * self._sx, h * self._sy
-
     #   S T A T E
 
     def saveGraphicState(self):
@@ -587,7 +508,7 @@ class FlatContext(BaseContext):
                 path.closePath()
             elif command == 'component':
                 (x, y), componentGlyph = t
-                #if not self.originTop:
+                # Flipping `y`-axis by default to conform to OS X / DrawBot origin at bottom.
                 y = -y
                 self.getGlyphPath(componentGlyph, (px+x, py+y), path)
 
@@ -947,7 +868,7 @@ class FlatContext(BaseContext):
 
         #pt = fPage.place(txt)
         # Stored typically as BabelString.cs in FlatContext mode.
-        return FlatBabelData(doc=fDoc, page=fPage, paragraphs=fParagraphs, runs=fRuns)
+        return FlatBabelData(builder=self.b, doc=fDoc, page=fPage, paragraphs=fParagraphs, runs=fRuns)
 
     #   F O N T
 
@@ -1038,17 +959,12 @@ class FlatContext(BaseContext):
         if p is None:
             p = 0, 0
 
-        #xTest, yTest = p
         x, y = self.translatePoint(p)
-        #xTest, yTest = self.getTransformed(xTest, yTest)
-        #print(x, y)
-        #print(xTest, yTest)
-        #self.save()
 
         doScale = w is not None or h is not None
 
         if doScale:
-            if HAS_PIL:
+            if self.hasPIL:
                 path = self.scaleImage(path, w, h)
 
                 # Now open the image in Flat.
@@ -1092,10 +1008,11 @@ class FlatContext(BaseContext):
 
         TODO: Make better match for all file types, transparency and spot
         color."""
-        return rgb(*to255(c.rgb))
+        return self.b.rgb(*to255(c.rgb))
 
     def _getShape(self):
         """Renders Pagebot FlatBuilder shape to a Flat shape."""
+        # TODO: Move inside FlatBezierpath.
         #if self._fill is noColor and self._stroke is noColor:
         #    self._fill = whiteColor
         shape = self.b.shape()
@@ -1348,25 +1265,21 @@ class FlatContext(BaseContext):
     def strokeWidth(self, w):
         self._strokeWidth = upt(w)
 
-    # Transform.
+    # Transformations.
 
     def transform(self, matrix, center=(0, 0)):
-        """
-        NOTE: not used, implemented as a transform3D object for now.
-        """
+        """NOTE: not used, implemented as a transform3D object for now."""
 
     def translate(self, dx, dy):
-        """Translates the origin by (dx, dy).
-        """
+        """Translates the origin by (dx, dy)."""
         self._ox += dx
         self._oy += dy
         self.transform3D = self.transform3D.translate(dx, dy, 0)
 
     def rotate(self, angle, center=None):
         """Rotates by angle.
-        TODO: use transform matrix.
-        FIXME: implement off-center rotation.
 
+        TODO: test off-center rotation.
         >>> context = FlatContext()
         >>> w = 800
         >>> h = 600
