@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: UTF-8 -*-
 # -----------------------------------------------------------------------------
-#
-#     P A G E B O T
+# #     P A G E B O T
 #
 #     Copyright (c) 2016+ Buro Petr van Blokland + Claudia Mens
 #     www.pagebot.io
@@ -17,7 +16,7 @@
 import copy
 import codecs
 from pagebot import getContext
-from pagebot.stylelib import styleLib # Library with named, predefined style dicts.
+from pagebot.stylelib import styleLib
 from pagebot.conditions.score import Score
 from pagebot.elements.page import Page
 from pagebot.elements.template import Template
@@ -59,6 +58,8 @@ class Document:
     >>> doc.solve()
     Score: 0 Fails: 0
     >>> doc.build()
+    >>> doc = Document(name='TestWhd', whd=(400, 400, 2), padding=(30, 40, 50, 60))
+    >>> doc = Document(name='TestWhd', wh=(400, 300), padding=(30, 40, 50, 60))
     """
 
     # Allows inherited versions of the Page class.
@@ -79,9 +80,8 @@ class Document:
         elif wh is not None:
             # Alternative ways to define size.
             size = wh
-
-        # Also accept size tuples.
-        if size is not None:
+        elif size is not None:
+            # Also accept size tuples.
             w, h, d = point3D(size) # Set
 
         # If no theme is defined, then use the default theme class to create an
@@ -192,10 +192,10 @@ class Document:
     docLib = property(_get_docLib)
 
     def _get_context(self):
+        """Gets the context from the view. Should always be initialized."""
         if hasattr(self, 'view') and hasattr(self.view, 'context'):
             return self.view.context
-        else:
-            return None
+        return None
 
     context = property(_get_context)
 
@@ -252,6 +252,10 @@ class Document:
         (<Page #66 default (300pt, 400pt)>, (66, 0))
         >>> doc.getPageNumber(page)
         (66, 0)
+        >>> page.pn
+        (66, 0)
+        >>> doc[(65, -1)]
+        <Page #65 default (300pt, 400pt)>
         >>> doc[-10] is None and doc[10000] is None # Answer None if out of range.
         True
         """
@@ -951,7 +955,7 @@ class Document:
         return pages
 
     def findPage(self, eId=None, name=None, pattern=None, pageSelection=None):
-        """Answer the first page found from the self.findPages(...) call. Answer None
+        """Answers the first page found from the self.findPages(...) call. Answers None
         if no page can be found matching the parameters."""
         pages = self.findPages(eId=eId, name=name, pattern=pattern, pageSelection=pageSelection)
         if pages:
@@ -959,13 +963,13 @@ class Document:
         return None
 
     def findBysId(self, sId):
-        """If defined, the system self.sId can be used to recursively find self or a child.
-        Answer None if nothing can be found that is exactly matching.
+        """If defined, the system self.sId can be used to recursively find self
+        or a child. Answers None if nothing can be found that matches exactly.
 
-        >>> from elements import *
         >>> doc = Document(sId=1234)
         >>> doc.view.sId = 7890
         >>> page = doc[1]
+        >>> from pagebot.elements.element import Element
         >>> e1 = Element(parent=page, name='e1', sId=2345)
         >>> e2 = Element(parent=e1, name='e2', sId=3456)
         >>> doc.findBysId(3456)
@@ -1444,7 +1448,7 @@ class Document:
 
         # Check if the context is supported by this view type.
         if context is None:
-            context = getContext(self.DEFAULT_CONTEXT_ID)
+            context = getContext()
 
         view = self.view = self.views[viewId] = viewClasses[viewId](name=name
                 or viewId, w=self.w, h=self.h, context=context)
@@ -1477,9 +1481,7 @@ class Document:
     def save(self, path, **kwargs):
         """Saves the document in native JSON source code file, representing all
         the current settings, including the current document.view.
-        """
 
-        """
         >>> doc = Document(w=300, h=400)
         >>> doc.save('/tmp/pagebot.document.json') # Saves document as a JSON file.
         """
@@ -1488,7 +1490,8 @@ class Document:
         d = dict(
             class_=self.__class__.__name__,
             name=self.name,
-            rootStyle=asNormalizedJSON(self.rootStyle),
+            # FIXME: unit types still need to be serialized.
+            #rootStyle=asNormalizedJSON(self.rootStyle),
             pages=asNormalizedJSON(self.pages),
             view=asNormalizedJSON(self.view),
         )
@@ -1530,6 +1533,9 @@ class Document:
         >>> score = doc.solve()
         >>> doc.view # PageView is default.
         <PageView>
+        >>> context.name in ('DrawBotContext', 'FlatContext')
+        True
+        >>> context.newPage(100, 100)
         >>> doc.export('_export/TestExportDoc.pdf')
         """
         self.build(path=path, multiPage=multiPage, **kwargs)
