@@ -34,6 +34,7 @@ from pagebot.elements.circle import Circle
 from pagebot.elements.polygon import Polygon
 from pagebot.elements.ruler import Ruler
 from pagebot.elements.docwrap import DocWrap
+from pagebot.elements.bezierpaths import BezierPaths
 
 # Page elements.
 from pagebot.elements.image import Image
@@ -71,23 +72,21 @@ from pagebot.elements.variablefonts.variablecircle import VariableCircle
 from pagebot.elements.designspacegraph.designspacegraph import DesignSpace, DesignSpaceGraph
 from pagebot.elements.variablefonts.specimen import TypeList, TypeFeatures, TypeGlyphSet, Waterfall
 
-def elementFromPath(path, name=None, **kwargs):
+def elementFromPath(path, context=None, name=None, **kwargs):
     """Answer the element that is best suitable to hold the data in the path.
     """
     extension = path2Extension(path).lower()
 
     if extension in IMAGE_TYPES:
-        e = newImage(path, name=name, **kwargs)
+        e = newImage(path, context=context, name=name, **kwargs)
+    elif extension in TEXT_TYPES:
+        e = newText(path, context=context, name=name, **kwargs)
     elif extension in FONT_TYPES:
         # TODO: Answer a default specimen element to show the font.
         e = None
     elif extension in MOVIE_TYPES:
         # TODO: Answer a MovieElement instance (to be developed)
         e = None
-    elif extension in TEXT_TYPES:
-        # TODO: Answer Text on the parsed content of the file, instead of
-        # the path.
-        e = newText(path, name=name, **kwargs)
     else:
         # If no extension-->element can be found.
         e = None
@@ -181,11 +180,11 @@ def newRuler(**kwargs):
 def newBezierCurve(**kwargs):
     return BezierCurve(**kwargs)
 
-def newPaths(paths=None, **kwargs):
-    """Creates a Paths element, holding BezierPath object(s) in the element
+def newBezierPaths(paths=None, **kwargs):
+    """Creates a Paths element, containing BezierPath objects in an element
     frame. The paths can be a single BezierPath instance or a list / tuple of
     instances. Not be confused with the filePath "path" in Image."""
-    return Paths(paths, **kwargs)
+    return BezierPaths(paths, **kwargs)
 
 def newGlyphPath(glyph, **kwargs):
     return GlyphPath(glyph, **kwargs)
