@@ -34,7 +34,7 @@ class Image(Element):
     >>> from pagebot.filepaths import getResourcesPath
     >>> imageFilePath = '/images/peppertom.png'
     >>> imagePath = getResourcesPath() + imageFilePath
-    >>> from pagebot import getContext #pagebot.contexts.markup.htmlcontext import HtmlContext
+    >>> from pagebot import getContext #pagebot.contexts.htmlcontext.htmlcontext import HtmlContext
     >>> from pagebot.constants import A4
     >>> from pagebot.document import Document
     >>> from pagebot.conditions import *
@@ -63,7 +63,7 @@ class Image(Element):
     >>> doc.solve()
     Score: 2 Fails: 0
     >>> e.w = 48 # Make the element into a thumbnail, scale the image to it.
-    >>> e._scaleImage(doc.view)
+    >>> #e._scaleImage(doc.view)
     """
     """
     >>> w, h = e.size # New scaled proportions
@@ -218,7 +218,7 @@ class Image(Element):
                 # Width is lead, calculate height.
                 u = self.ih * upt(self._w / iwpt)
             else:
-                # Undefined and without parent, answer original image width.
+                # Undefined and without parent, answer original image height.
                 u = self.ih
         else:
             # In case relative units, use the right kind of base.
@@ -1360,6 +1360,7 @@ Transitions from one image to another by simulating a swiping action.
 
 Attributes: targetImage an Image object, extent a tuple (x, y, w, h), color RGBA tuple Color (r, g, b, a), time a float, angle a float in degrees, width a float, opacity a float.
         """
+
 if __name__ == '__main__':
     import doctest
     sys.exit(doctest.testmod()[0])
