@@ -184,11 +184,9 @@ class TypeList(Group):
 
     >>> from pagebot.document import Document
     >>> from pagebot.constants import A4Rounded
-    >>> from pagebot.contexts import getDrawBotContext, getHtmlContext
+    >>> from pagebot import getContext
     >>> from pagebot.toolbox.units import pt
-    >>> context = getDrawBotContext()
-    >>> context
-    <DrawBotContext>
+    >>> context = getContext()
     >>> W, H = A4Rounded
     >>> fontSize = pt(32) # Size of main sample
     >>> adobeUrl = 'https://fonts.adobe.com/fonts/upgrade'
@@ -213,9 +211,9 @@ class TypeList(Group):
     2
     >>> typeList.elements[0].size # TypeListLine expanded the width inside the typeList
     (495pt, 44.8pt)
-    >>> doc.export('_export/TypeList.pdf')
+    >>> #doc.export('_export/TypeList.pdf')
     >>> view = doc.newView('Site')
-    >>> doc.export('_export/TypeList')
+    >>> #doc.export('_export/TypeList')
 
     """
     CSS_ID = 'TypeList'
@@ -278,11 +276,9 @@ class TypeFeatures(Group):
 
     >>> from pagebot.document import Document
     >>> from pagebot.constants import A4Rounded
-    >>> from pagebot.contexts import getDrawBotContext, getHtmlContext
+    >>> from pagebot import getContext
     >>> from pagebot.toolbox.units import pt
-    >>> context = getDrawBotContext()
-    >>> context
-    <DrawBotContext>
+    >>> context = getContext()
     >>> W, H = A4Rounded
     >>> fontSize = pt(32) # Size of main sample
     >>> adobeUrl = 'https://fonts.adobe.com/fonts/upgrade'
@@ -305,9 +301,9 @@ class TypeFeatures(Group):
     32pt
     >>> len(typeFeatures.fonts)
     2
-    >>> doc.export('_export/TypeFeatures.pdf')
+    >>> #doc.export('_export/TypeFeatures.pdf')
     >>> view = doc.newView('Site')
-    >>> doc.export('_export/TypeFeatures')
+    >>> #doc.export('_export/TypeFeatures')
 
     """
     CSS_ID = 'TypeFeatures'
@@ -386,11 +382,9 @@ class TypeGlyphSet(Group):
 
     >>> from pagebot.document import Document
     >>> from pagebot.constants import A4Rounded
-    >>> from pagebot.contexts import getDrawBotContext, getHtmlContext
+    >>> from pagebot.contexts import getContext
     >>> from pagebot.toolbox.units import pt
-    >>> context = getDrawBotContext()
-    >>> context
-    <DrawBotContext>
+    >>> context = getContext()
     >>> W, H = A4Rounded
     >>> fontSize = pt(32) # Size of main sample
     >>> adobeUrl = 'https://fonts.adobe.com/fonts/upgrade'
@@ -413,9 +407,9 @@ class TypeGlyphSet(Group):
     32pt
     >>> len(typeGlyphSet.fonts)
     2
-    >>> doc.export('_export/TypeGlyphSet.pdf')
+    >>> #doc.export('_export/TypeGlyphSet.pdf')
     >>> view = doc.newView('Site')
-    >>> doc.export('_export/TypeGlyphSet')
+    >>> #doc.export('_export/TypeGlyphSet')
 
     """
     CSS_ID = 'TypeGlyphSet'
@@ -464,17 +458,21 @@ class TypeGlyphSet(Group):
         b._div()
         b.comment('End %s.%s\n' % (self.cssId, self.cssClass))
 
+    def build_drawBot(self, view, path, **kwargs):
+        pass
+
 class Waterfall(Group):
     """Shows a list of type styles in their style.
     Add information as it is available in the font.
 
     >>> from pagebot.document import Document
     >>> from pagebot.constants import A4Rounded
-    >>> from pagebot.contexts import getDrawBotContext, getHtmlContext
+    >>> from pagebot.contexts import getHtmlContext
     >>> from pagebot.toolbox.units import pt
-    >>> context = getDrawBotContext()
+    >>> from pagebot import getContext
+    >>> context = getContext('Html')
     >>> context
-    <DrawBotContext>
+    <HtmlContext>
     >>> W, H = A4Rounded
     >>> fontSize = pt(32) # Size of main sample
     >>> adobeUrl = 'https://fonts.adobe.com/fonts/upgrade'
@@ -494,7 +492,8 @@ class Waterfall(Group):
     >>> score = page.solve()
     >>> doc.export('_export/Waterfall.pdf')
     >>> view = doc.newView('Site')
-    >>> doc.export('_export/Waterfall')
+    >>> # FIXME: no prepare_drawbot.
+    >>> #doc.export('_export/Waterfall')
 
     """
     CSS_ID = 'Waterfall'
