@@ -1,3 +1,4 @@
+#!/usr/bin/env python3
 # -*- coding: UTF-8 -*-
 # -----------------------------------------------------------------------------
 #
@@ -27,7 +28,20 @@ from pagebot.fonttoolbox.analyzers.apoint import APoint
 def calculateAngle(p1, p2, inDegrees=True):
     """Calculate the angle between points p1 and p2. Points can be either 2D or
     3D point tuples or Point instances. In the case of Point3D, only the 2D
-    projection in (x, y) plane is calculated."""
+    projection in (x, y) plane is calculated.
+
+
+    >>> p1 = (0, 0)
+    >>> p2 = (100, 100)
+    >>> angle = calculateAngle(p1, p2)
+    >>> angle
+    45.0
+    >>> p1 = (0, 0)
+    >>> p2 = (0, 30)
+    >>> angle = calculateAngle(p1, p2, inDegrees=False)
+    >>> angle == math.radians(90)
+    True
+    """
     xDiff = p2[0] - p1[0]
     yDiff = p2[1] - p1[1]
     angle = math.atan2(yDiff, xDiff)
@@ -39,7 +53,18 @@ def angleOfLines(p1, p2, q1, q2, inDegrees=True):
     """Answers the angle difference (radials or default degrees) between
     p1-->p2 and q1-->q2. Points can be either 2D or 3D point tuples or Point
     instances. In the case of Point3D, only the 2D projection in (x, y) plane
-    is calculated."""
+    is calculated.
+
+    >>> p1 = (0, 0)
+    >>> p2 = (100, 100)
+    >>> q1 = (100, 0)
+    >>> q2 = (0, 100)
+    >>> angleOfLines(p1, p2, q1, q1)
+    -45.0
+    >>> angle = angleOfLines(q1, q2, p1, p1, inDegrees=False)
+    >>> angle == math.radians(-135.0)
+    True
+    """
     angle1 = calculateAngle(p1, p2, inDegrees)
     angle2 = calculateAngle(q1, q2, inDegrees)
     angle = angle2 - angle1
@@ -56,12 +81,42 @@ class APointContext:
     from the point context in relation to the neighbor points. The total of 7
     points is derived from the average construction of a serif, so it is
     possible to hold (and interpret) an entire serif sequence inside one point
-    context."""
+    context.
+
+
+    """
     PARALLEL_TOLERANCE = 2 # Difference tolerance angle in degrees to take point contexts as parallel
 
     def __init__(self, points, index=None, contourIndex=None, clockwise=None, glyphName=None):
-        """Points list is supposed to contain Point instances, not point lists.
-        We need the extra storage, e.g. for point type that Point holds."""
+        """Points context for Point instances, three before, one in the middle,
+        and three after. We need the extra storage, e.g. for point type that
+        Point holds.
+
+        >>> b1 = APoint((0, 0))
+        >>> b2 = APoint((0, 100))
+        >>> b3 = APoint((40, 200))
+        >>> p1 = APoint((100, 200))
+        >>> a1 = APoint((200, 200))
+        >>> a2 = APoint((140, 100))
+        >>> a3 = APoint((40, 80))
+        >>> pc = APointContext((b1, b2, b3, p1, a1, a2, a3))
+        >>> pc[0]
+        100
+        >>> pc[1]
+        200
+        >>> # TODO: find some positive results.
+        >>> pc.isInflection()
+        False
+        >>> pc.isDiagonal()
+        False
+        >>> pc.isParallel(pc)
+        True
+        >>> #pc.getProjectedPoint(a3)
+        >>> pc.nextOnCurvePoint
+        APoint(200,200,On)
+        >>> pc.prevOnCurvePoint
+        APoint(40,200,On)
+        """
         assert len(points) == 7
         self.p_3, self.p_2, self.p_1, self.p, self.p1, self.p2, self.p3 = points
         self.contourIndex = contourIndex
@@ -72,6 +127,9 @@ class APointContext:
         self._angle = None  # Cache axis once calculated.
 
     def __getitem__(self, index):
+        """
+        Gets the main, middle point within the point context.
+        """
         return self.p[index]
 
     def __lt__(self, p):
@@ -130,6 +188,10 @@ class APointContext:
         """
         return self.p >= p.p
 
+    '''
+    # These seem to be based on APoint instead of APointContext. Does it make
+    # sense to do math operations on point contexts?
+
     def __sub__(self, p):
         """Subtract the points. Result is a point3D tuple.
 
@@ -175,6 +237,7 @@ class APointContext:
         """
         assert isinstance(v, (int, float))
         return self.p[0] / v, self.p[1] / v, self.p[2] / v
+    '''
 
 
     def _get_x(self):
@@ -215,6 +278,14 @@ class APointContext:
     normalizedAngle = property(_get_normalizedAngle)
 
     def __repr__(self):
+        """
+        >>> o = APoint((0, 0))
+        >>> pc1 = APointContext((o, o, o, APoint((100, 200)), o, o, o), index=1, contourIndex=2, clockwise=True, glyphName='bla')
+        >>> pc1[1]
+        200
+        >>> print(pc1)
+        pc[index:1](100,200) (bla)
+        """
         s = 'pc'
         if self.index is not None:
             s += '[index:%s]' % self.index
