@@ -1,3 +1,4 @@
+#!/usr/bin/env python3
 # -*- coding: UTF-8 -*-
 # -----------------------------------------------------------------------------
 #
@@ -19,8 +20,22 @@ import codecs
 
 def readRE(path, pattern):
     """If fileName is pointing to a non-XML file, then try to read and apply
-    the pattern on the content.  Answer the result of the pattern match."""
+    the pattern on the content. Answer the result of the pattern match.
+
+    >>> from pagebot.filepaths import getResourcesPath
+    >>> resourcesPath = getResourcesPath()
+    >>> testHtml = resourcesPath + '/templates/test.html'
+    >>> testString = '<html><body><p>test paragraph.</p></body></html>'
+    >>> import re
+    >>> reNoTags = re.compile(r'<[^>]*|([^<>]*)')
+    >>> result = readRE(testHtml, reNoTags)
+    """
     f = codecs.open(path, mode="r", encoding="utf-8")
     text = f.read()
     f.close()
     return pattern.findall(text)
+
+if __name__ == "__main__":
+    import doctest
+    import sys
+    sys.exit(doctest.testmod()[0])
