@@ -19,9 +19,16 @@
 import xml.etree.ElementTree as ET
 
 def readXML(path, xPath=None):
-    """Read the XML from path and answer the compiled etree."""
+    """Read the XML from path and answer the compiled etree.
+
+    >>> from pagebot.filepaths import getResourcesPath
+    >>> resourcesPath = getResourcesPath()
+    >>> testSvg = resourcesPath + '/templates/test.svg'
+    >>> root = readHTML(testSvg, xPath=None)
+    >>> #root
+    """
     fileExtension = path.split('.')[-1].lower()
-    assert fileExtension.lower() in ('xml', 'xsl', 'html')
+    assert fileExtension.lower() in ('xml', 'xsl', 'html', 'svg', 'ufo')
     tree = ET.parse(path)
     root = tree.getroot() # Get the root element of the tree.
 
@@ -31,5 +38,21 @@ def readXML(path, xPath=None):
     return root
 
 def readHTML(path, xPath=None):
-    """Read the HTML body tag from path and answer the compiled etree."""
+    """Read the HTML body tag from path and answer the compiled etree.
+
+
+    >>> from pagebot.filepaths import getResourcesPath
+    >>> resourcesPath = getResourcesPath()
+    >>> testHtml = resourcesPath + '/templates/test.html'
+    >>> body = readHTML(testHtml)[0]
+    >>> body.tag
+    'body'
+    >>> len(list(body))
+    2
+    """
     return readXML(path, xPath='body')
+
+if __name__ == "__main__":
+    import doctest
+    import sys
+    sys.exit(doctest.testmod()[0])
